@@ -56,7 +56,7 @@ sub checkconfig () {
 	$config{mdwn_alpha_lists} = 0 unless defined $config{mdwn_alpha_lists};
 }
 
-our $markdown_sub;
+my $markdown_sub;
 sub htmlize (@) {
 	my %params=@_;
 	my $content = $params{content};
@@ -77,7 +77,9 @@ sub htmlize (@) {
 				$markdown_sub=sub {
 					my %flags=( use_metadata => 0 );
 
-					$flags{disable_footnotes}=not $config{mdwn_footnotes};
+					if ($config{mdwn_footnotes}) {
+						$flags{disable_footnotes}=1;
+					}
 
 					Text::MultiMarkdown::markdown(shift, \%flags);
 				}
@@ -87,55 +89,6 @@ sub htmlize (@) {
 		    (! exists $config{nodiscount} || ! $config{nodiscount})) {
 			eval q{use Text::Markdown::Discount};
 			if (! $@) {
-				my $markdown = \&Text::Markdown::Discount::markdown;
-				my $always_flags = 0;
-
-				# Disable Pandoc-style % Title, % Author, % Date
-				# Use the meta plugin instead
-				$always_flags |= Text::Markdown::Discount::MKD_NOHEADER();
-
-				# Disable Unicodification of quote marks, em dashes...
-				# Use the typography plugin instead
-				$always_flags |= Text::Markdown::Discount::MKD_NOPANTS();
-
-				# Workaround for discount's eliding of <style> blocks.
-				# https://rt.cpan.org/Ticket/Display.html?id=74016
-				if (Text::Markdown::Discount->can('MKD_NOSTYLE')) {
-					$always_flags |= Text::Markdown::Discount::MKD_NOSTYLE();
-				}
-				elsif ($markdown->('<style>x</style>', 0) !~ '<style>' &&
-					$markdown->('<style>x</style>', 0x00400000) =~ m{<style>x</style>}) {
-					$always_flags |= 0x00400000;
-				}
-
-				# Enable fenced code blocks in libmarkdown >= 2.2.0
-				# https://bugs.debian.org/888055
-				if (Text::Markdown::Discount->can('MKD_FENCEDCODE')) {
-					$always_flags |= Text::Markdown::Discount::MKD_FENCEDCODE();
-				}
-				elsif ($markdown->("~~~\nx\n~~~", 0) !~ m{<pre\b} &&
-					$markdown->("~~~\nx\n~~~", 0x02000000) =~ m{<pre\b}) {
-					$always_flags |= 0x02000000;
-				}
-
-				# PHP Markdown Extra-style term\n: definition -> <dl>
-				if (Text::Markdown::Discount->can('MKD_DLEXTRA')) {
-					$always_flags |= Text::Markdown::Discount::MKD_DLEXTRA();
-				}
-				elsif ($markdown->("term\n: def\n", 0) !~ m{<dl>} &&
-					$markdown->("term\n: def\n", 0x01000000) =~ m{<dl>}) {
-					$always_flags |= 0x01000000;
-				}
-
-				# Allow dashes and underscores in tag names
-				if (Text::Markdown::Discount->can('MKD_GITHUBTAGS')) {
-					$always_flags |= Text::Markdown::Discount::MKD_GITHUBTAGS();
-				}
-				elsif ($markdown->('<foo_bar>', 0) !~ m{<foo_bar} &&
-					$markdown->('<foo_bar>', 0x08000000) =~ m{<foo_bar\b}) {
-					$always_flags |= 0x08000000;
-				}
-
 				$markdown_sub=sub {
 					my $t=shift;
 
@@ -143,7 +96,15 @@ sub htmlize (@) {
 					# https://rt.cpan.org/Ticket/Display.html?id=73657
 					return "" if $t=~/^\s*$/;
 
-					my $flags=$always_flags;
+					my $flags=0;
+
+					# Disable Pandoc-style % Title, % Author, % Date
+					# Use the meta plugin instead
+					$flags |= Text::Markdown::Discount::MKD_NOHEADER();
+
+					# Disable Unicodification of quote marks, em dashes...
+					# Use the typography plugin instead
+					$flags |= Text::Markdown::Discount::MKD_NOPANTS();
 
 					if ($config{mdwn_footnotes}) {
 						$flags |= Text::Markdown::Discount::MKD_EXTRA_FOOTNOTE();
@@ -153,6 +114,17 @@ sub htmlize (@) {
 						$flags |= Text::Markdown::Discount::MKD_NOALPHALIST();
 					}
 
+					# Workaround for discount's eliding
+					# of <style> blocks.
+					# https://rt.cpan.org/Ticket/Display.html?id=74016
+					if (Text::Markdown::Discount->can("MKD_NOSTYLE")) {
+						$flags |= Text::Markdown::Discount::MKD_NOSTYLE();
+					}
+					else {
+						# This is correct for the libmarkdown.so.2 ABI
+						$flags |= 0x00400000;
+					}
+
 					return Text::Markdown::Discount::markdown($t, $flags);
 				}
 			}
